@@ -1,7 +1,7 @@
 /*
  * Card games
  *
- * Copyright (C) Evan Harris, 1991, 1994
+ * Copyright (C) Evan Harris, 1991, 1994, 1995.
  *
  * Permission is granted to freely redistribute and modify this code,
  * providing the author(s) get credit for having written it.
@@ -27,7 +27,3 @@ void	EndDisplay(void);
 
 void	InitRandom(unsigned char);
 long	Random(long);
-
-void	RenderMousePointer(int, int, int, int);
-void	RestoreUnderMousePointer(int, int, int *);
-int	SaveUnderMousePointer(int, int, int *);
